@@ -852,7 +852,7 @@ void Matern_Prior::Print(FILE *outfile)
 
 double Matern_Prior::log_HierPrior(void)
 {
-  double lpdf, p;
+  double lpdf;
   lpdf = 0.0;
 
   /* mixture prior for the range parameter, d */
