@@ -1560,7 +1560,7 @@ void MrExpSep_Prior::Print(FILE *outfile)
 
 double MrExpSep_Prior::log_HierPrior(void)
 {
- double lpdf, p;
+ double lpdf;
  
  lpdf = 0.0;
 
