@@ -841,7 +841,7 @@ void MrMatern_Prior::Print(FILE *outfile)
 
 double MrMatern_Prior::log_HierPrior(void)
 {
- double lpdf, p;
+ double lpdf;
  
  lpdf = 0.0;
 
