@@ -32,7 +32,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
-#include <Rmath.h>
+#include <Rmath.h> 
 #include "randomkit.h"
 
 /* for Windows and other OS's without drand support,
@@ -53,10 +53,14 @@ unsigned long s;
 {
  switch (RNG) {
  case CRAN: 
+#ifdef RPRINT
    if(getrngstate) GetRNGstate();
    else warning("cannot generate multiple CRAN RNG states");
    getrngstate = 0;
    return NULL;
+# else
+   error("cannot use R RNG when not compiling from within R");
+#endif
  case RK: {
    rk_state* state = (rk_state*) malloc(sizeof(rk_state));
    rk_seed(s, state);
@@ -124,9 +128,13 @@ void deleteRNGstate(void *state)
 {
  switch (RNG) {
  case CRAN:
+#ifdef RPRINT
    if(!getrngstate) PutRNGstate();
    getrngstate = 1;
    break;
+#else
+   error("cannot use R RNG when not compiling from within R");
+#endif
  case RK:
    free((rk_state*) state);
    break;
@@ -358,27 +366,31 @@ double rexpo(double lambda, void *state)
 
 double rgamma1(double alpha, void *state)
 {
-    double uniform0, uniform1;
-    double random, x;
-    /* int done = 0; */
-    uniform0 = runi(state);
-    uniform1 = runi(state);
-    if (uniform0 > M_E/(alpha + M_E))
+  double uniform0, uniform1;
+  double random, x;
+  
+  /* sanity check */
+  assert(alpha > 0);
+  
+  /* int done = 0; */
+  uniform0 = runi(state);
+  uniform1 = runi(state);
+  if (uniform0 > M_E/(alpha + M_E))
     {
-        random = -log((alpha + M_E)*(1-uniform0)/(alpha*M_E));
-        if ( uniform1 > pow(random,alpha - 1))
-            return -1;
-        else 
-            return random;
+      random = -log((alpha + M_E)*(1-uniform0)/(alpha*M_E));
+      if ( uniform1 > pow(random,alpha - 1))
+	return -1;
+      else 
+	return random;
     }
-    else
+  else
     {
-        x = (alpha + M_E) * uniform0 / M_E;
-        random = pow(x,1/alpha);
-        if ( uniform1 > exp(-random))
-            return -1;
-        else
-            return random;
+      x = (alpha + M_E) * uniform0 / M_E;
+      random = pow(x,1/alpha);
+      if ( uniform1 > exp(-random))
+	return -1;
+      else
+	return random;
     } 
 }
 
@@ -393,38 +405,42 @@ double rgamma1(double alpha, void *state)
 
 double rgamma2(double alpha, void *state)
 {
-    double uniform1,uniform2;
-    double c1,c2,c3,c4,c5,w;
-    double random;
-    int done = 1;
-    c1 = alpha - 1;
-    c2 = (alpha - 1/(6 * alpha))/c1;
-    c3 = 2 / c1;
-    c4 = c3 + 2;
-    c5 = 1 / sqrt(alpha);
-    do
+  double uniform1,uniform2;
+  double c1,c2,c3,c4,c5,w;
+  double random;
+  int done = 1;
+  
+  /* sanity check */
+  assert(alpha > 0);
+  
+  c1 = alpha - 1;
+  c2 = (alpha - 1/(6 * alpha))/c1;
+  c3 = 2 / c1;
+  c4 = c3 + 2;
+  c5 = 1 / sqrt(alpha);
+  do
     {
-        uniform1 = runi(state);
-        uniform2 = runi(state);
-        if (alpha > 2.5)
+      uniform1 = runi(state);
+      uniform2 = runi(state);
+      if (alpha > 2.5)
         {
-             uniform1 = uniform2 + c5 * (1 - 1.86 * uniform1);
+	  uniform1 = uniform2 + c5 * (1 - 1.86 * uniform1);
         }
     }
-    while ((uniform1 >= 1) || (uniform1 <= 0));
-
-    w = c2 * uniform2 / uniform1;
-    if ((c3 * uniform1 + w + 1/w) > c4)
+  while ((uniform1 >= 1) || (uniform1 <= 0));
+  
+  w = c2 * uniform2 / uniform1;
+  if ((c3 * uniform1 + w + 1/w) > c4)
     {
-        if ((c3 * log(uniform1) - log(w) + w) >= 1)
+      if ((c3 * log(uniform1) - log(w) + w) >= 1)
         {
-            done = 0;
+	  done = 0;
         }
     }
-    if (done == 0)
-        return -1;
-    random = c1 * w; 
-    return random;
+  if (done == 0)
+    return -1;
+  random = c1 * w; 
+  return random;
 }
 
 
@@ -438,18 +454,22 @@ double rgamma2(double alpha, void *state)
 
 double rgamma_wb(double alpha, double beta, void *state)
 {
-    double random = 0;
-    if (alpha < 1)
-        do {
-        random = rgamma1(alpha, state)/beta; 
-        } while (random < 0 );
-    if (alpha == 1)
-        random = rexpo(1.0, state)/beta; 
-    if (alpha > 1)
-        do {
-        random = rgamma2(alpha, state)/beta; 
-        } while (random < 0);
-    return random;
+  double random = 0;
+  
+  /* sanity checks */
+  assert(alpha>0 && beta>0);
+  
+  if (alpha < 1)
+    do {
+      random = rgamma1(alpha, state)/beta; 
+    } while (random < 0 );
+  if (alpha == 1)
+    random = rexpo(1.0, state)/beta; 
+  if (alpha > 1)
+    do {
+      random = rgamma2(alpha, state)/beta; 
+    } while (random < 0);
+  return random;
 }
 
 
@@ -468,6 +488,9 @@ double alpha, beta;
 void *state;
 {
    int i;
+
+   /* sanity checks */
+   assert(alpha>0 && beta >0);
 	
    /* get CASES draws from a gamma */
    for(i=0; i< cases; i++) x[i] = 1.0 / rgamma_wb(alpha, beta, state);
