@@ -26,7 +26,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
-#include <Rmath.h>
+#include <Rmath.h> 
 #include "rand_pdf.h"
 #include "matrix.h"
 #include "linalg.h"
@@ -173,7 +173,13 @@ unsigned int n;
 double *p, *x, a, b;
 {
   int i;
+  
+  /* sanity checks */
+  assert(a>0 && b>0);
+
+  /* evaluate the pdf for each x */
   for(i=0; i<n; i++) {
+    assert(x[i] > 0);
     p[i] = a*log(b) - lgammafn(a) + (a-1)*log(x[i]) - b*x[i]; 
   }
 }
@@ -192,7 +198,13 @@ unsigned int n;
 double *p, *x, a, b;
 {
   int i;
+
+  /* sanity checks */
+  assert(a>0 && b>0);
+
+  /* evaluate the pdf for each x */
   for(i=0; i<n; i++) {
+    assert(x[i] >= 0);
     p[i] = a*log(b) - lgammafn(a) - (a+1)*log(x[i]) - b/x[i]; 
   }
 }
@@ -203,7 +215,7 @@ double *p, *x, a, b;
  * gampdf_log:
  * 
  * logarithm of the density of n x values distributed * as Gamma(a,b).  
- * p must be pre-alloc'd n-array
+ * p must be pre-alloc'd n-array; not using Gelman parameterization
  */
 
 void gampdf_log(p, x, a, b, n)
@@ -211,7 +223,13 @@ unsigned int n;
 double *p, *x, a, b;
 {
   int i;
+
+  /* sanity checks */
+  assert(a>0 && b>0);
+  
+  /* evaluate the pdf for each x */
   for(i=0; i<n; i++) {
+    assert(x[i] > 0);
     p[i] = - a*log(b) - lgammafn(a) + (a-1)*log(x[i]) - x[i]/b; 
   }
 }
@@ -442,3 +460,49 @@ void wishpdf_log_R(double *W_in, double *S_in, int *n_in, int *nu_in,
   delete_matrix(W);
   delete_matrix(S);
 }
+
+
+/*
+ * temper:
+ *
+ * apply temperature temp to pdf density p; i.e.,
+ * take p^temp when uselog = 0, and temp*k, when
+ * uselog = 1, assuming that p is in log space
+ */
+
+double temper(double p, double temp, int uselog)
+{
+  double tp;
+
+  /* remove this later */
+  if(temp != 1.0) warning("temper(): temp = %g is not 1.0", temp);
+
+  if(uselog) tp = temp * p;
+  else {
+    if(temp == 1.0) tp = p;
+    else if(temp == 0.0) tp = 1.0;
+    else tp = pow(p, temp);
+  }
+
+  return tp;
+}
+
+
+/*
+ * temper_invgam:
+ *
+ * apply temperature t to the alpha (a) and beta (b) parameters
+ * to the inverse gamma distribution
+ */
+
+void temper_invgam(double *a, double *b, double temp)
+{
+  /* remove this later */
+  if(temp != 1.0) warning("temper_invgam(): temp = %g is not 1.0", temp);
+
+  *a = temp*(*a+1.0) - 1.0;
+  *b = temp * (*b);
+
+  /* sanity check */
+  assert(*a > 0 && *b > 0);
+}
