@@ -1,4 +1,4 @@
-#/******************************************************************************** 
+/******************************************************************************** 
  *
  * Bayesian Regression and Adaptive Sampling with Gaussian Process Trees
  * Copyright (C) 2005, University of California
@@ -38,5 +38,7 @@ double log_determinant(double **M, unsigned int n);
 double log_determinant_dup(double **M, unsigned int n);
 double log_determinant_chol(double **M, unsigned int n);
 double wishpdf_log(double **x, double **S, unsigned int n, unsigned int nu);
+double temper(double p, double temp, int uselog);
+void temper_invgam(double *a, double *b, double temp);
 
 #endif
